==> collective.easytemplate-0.7.5.tar.gz: collective.easytemplate-0.7.5/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of collective.easytemplate
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '0.7.5'

long_description = read('docs', 'Introduction.txt') + \
    read('docs', 'TemplateEngine.txt') + \
    read('docs', 'Objects.txt') + \
    read('docs', 'Security.txt') + \
    read('docs', 'Authoring.txt') + \
    read('docs', 'Context.txt') + \
    read('docs', 'Tags.txt') + \
    read('docs', 'RegisteringTags.txt')

tests_require=['zope.testing']

setup(name='collective.easytemplate',
      version=version,
      description="Simple scripting for Plone pages",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        ],
      keywords='plone cheetah jinja template kupu scripting dynamic page',
      author='Mikko Ohtamaa',
      author_email='mikko.ohtamaa@twinapex.com',
      url='http://plone.org/products/easy-template',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'Jinja2',
                        'plone.portlet.static',
                        'collective.templateengines'
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'collective.easytemplate.tests',
      entry_points="""
      # -*- entry_points -*-
      """,
      paster_plugins = ["ZopeSkel"],
      )

==> collective.easytemplate-0.7.6.tar.gz: collective.easytemplate-0.7.6/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of collective.easytemplate
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read().decode("utf-8")

version = '0.7.6'

long_description = read('docs', 'Introduction.txt') + \
    read('docs', 'TemplateEngine.txt') + \
    read('docs', 'Objects.txt') + \
    read('docs', 'Security.txt') + \
    read('docs', 'Authoring.txt') + \
    read('docs', 'Context.txt') + \
    read('docs', 'Tags.txt') + \
    read('docs', 'RegisteringTags.txt')

tests_require=['zope.testing']

setup(name='collective.easytemplate',
      version=version,
      description="Simple scripting for Plone pages",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        ],
      keywords='plone cheetah jinja template kupu scripting dynamic page html',
      author='mFabrik Research Oy',
      author_email='info@mfabrik.com',
      url='http://plone.org/products/easy-template',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'Jinja2',
                        'plone.portlet.static',
                        'collective.templateengines'
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'collective.easytemplate.tests',
      entry_points="""
      # -*- entry_points -*-
      """,
      paster_plugins = ["ZopeSkel"],
      )
